S+LEAF: Semiseparable + leaf matrix
===================================

Read the documentation at `<https://obswww.unige.ch/~delisle/spleaf/doc/>`_.

Contribute
----------

Everyone is welcome to open issues and/or contribute code via pull-requests.
A SWITCH edu-ID account is necessary to sign in to `<https://gitlab.unige.ch>`_.
If you don't have an account, you can easily create one at `<https://eduid.ch>`_.
Then you can sign in to `<https://gitlab.unige.ch>`_ by selecting "SWITCH edu-ID" as your organisation.
